0130f6314dc5ec61189863dc025aad9fbd91c717
markd
  Thu Dec 7 15:07:19 2023 -0800
Add -tsv option to bigBedToBed to create a TSV-style header that can be used with tools that work with TSVs, such as python CVS/TSV reader and Pandas

diff --git src/inc/bigBedCmdSupport.h src/inc/bigBedCmdSupport.h
index 34edeb5..2c8a964 100644
--- src/inc/bigBedCmdSupport.h
+++ src/inc/bigBedCmdSupport.h
@@ -1,13 +1,16 @@
 /* bigBedCmdSupport - functions to support writing bigBed related commands. */
 
 /* Copyright (C) 2022 The Regents of the University of California 
  * See kent/LICENSE or http://genome.ucsc.edu/license/ for licensing information. */
 
 #ifndef bigBedCmdSupport_h
 #define bigBedCmdSupport_h
 #include "bigBed.h"
 
 void bigBedCmdOutputHeader(struct bbiFile *bbi, FILE *f);
-/* output a header from the autoSql in the file */
+/* output a autoSql-style header from the autoSql in the file */
+
+void bigBedCmdOutputTsvHeader(struct bbiFile *bbi, FILE *f);
+/* output a TSV-style header from the autoSql in the file */
 
 #endif